@@ -340,7 +340,7 @@ IPA_xlsxAnalyzer <- function(spreadsheet) {
       output_path <- gsub("\\", "/", PARAM[x0010, 2], fixed=TRUE)
       PARAM[x0010, 2] <- output_path
       if (!dir.exists(output_path)) {
-        tryCatch(dir.create(output_path), error = function(e){print("ERROR!!! Problem with PARAM0010! R can only create one folder!")})
+        tryCatch(dir.create(output_path), warning = function(w){message("WARNING!!! Problem with PARAM0010! R can only create one folder!")})
         if (!dir.exists(output_path)) {
           checkpoint_parameter <- FALSE
         }
@@ -361,14 +361,17 @@ IPA_xlsxAnalyzer <- function(spreadsheet) {
         }
       }
       ##
-      x0012 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0012'), 2])
-      if (is.na(x0012)) {
-        print("ERROR!!! Problem with PARAM0012! This parameter should be a positive number!")
+      x0012 <- which(PARAM[, 1] == 'PARAM0012')
+      if (length(x0012) == 0) {
+        print("ERROR!!! Problem with PARAM0012!")
         checkpoint_parameter <- FALSE
       } else {
-        if (x0012 <= 0) {
-          print("ERROR!!! Problem with PARAM0012! This parameter should be a positive number!")
-          checkpoint_parameter <- FALSE
+        massDifferenceIsotopes <- tryCatch(as.numeric(PARAM[x0012, 2]), error = function(e) {1.003354835336}, warning = function(w) {1.003354835336})     # Mass difference for isotopic pairs
+        PARAM[x0012, 2] <- massDifferenceIsotopes
+        if (massDifferenceIsotopes <= 1.00336 & massDifferenceIsotopes >= 1.00335) {
+          print("Carbon isotopes are selected for ion pairing!")
+        } else {
+          print(paste0("Mass difference to pair isotopes are = '", massDifferenceIsotopes, " Da'!"))
         }
       }
       #################### Chromatographic peak detection ########################
